@@ -454,12 +454,10 @@ fn quote(q: Quote) -> io::Result<()> {
 }
 
 fn quote_chunk(q: &Quote, buf: String) -> io::Result<()> {
-    let v = if let QuotationOutput::Symbol(_) = q.output {
-        Value::symbol(&buf).wrap()
-    } else {
-        Value::String(buf).wrap()
-    };
-    output_one(q, &v)
+    match q.output {
+        QuotationOutput::Symbol(_) => output_one(q, &IOValue::symbol(&buf)),
+        _ => output_one(q, &IOValue::new(buf)),
+    }
 }
 
 fn quote_terminated_strings(delimiter: u8, q: &Quote, s: &StringQuotation) -> io::Result<()> {
